Stan Math Library: stan::VectorView< T, is_array, true > Class Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Types | Public Member Functions | List of all members
stan::VectorView< T, is_array, true > Class Template Reference

`#include <VectorView.hpp>`

## Public Types
typedef boost::conditional< boost::is_const< T >::value, typename boost::add_const< typename scalar_type< T >::type >::type, typename scalar_type< T >::type >::type | scalar_t

## Public Member Functions
| VectorView ()
template<typename X >
| VectorView (X x)
scalar_t & | operator[] (int i)
scalar_t & | operator[] (int i) const

## Detailed Description

### template<typename T, bool is_array>
class stan::VectorView< T, is_array, true >

Definition at line 75 of file VectorView.hpp.

## Member Typedef Documentation

template<typename T , bool is_array>

typedef boost::conditional<boost::is_const<T>::value, typename boost::add_const< typename scalar_type<T>::type>::type, typename scalar_type<T>::type>::type stan::VectorView< T, is_array, true >::scalar_t

Definition at line 81 of file VectorView.hpp.

## Constructor & Destructor Documentation

template<typename T , bool is_array>

stan::VectorView< T, is_array, true >::VectorView | ( |  | ) |
| inline

Definition at line 82 of file VectorView.hpp.

template<typename T , bool is_array>
template<typename X >

stan::VectorView< T, is_array, true >::VectorView | ( | X | x | ) |
| inlineexplicit

Definition at line 85 of file VectorView.hpp.

## Member Function Documentation

template<typename T , bool is_array>

scalar_t& stan::VectorView< T, is_array, true >::operator[] | ( | int | i | ) |
| inline

Definition at line 87 of file VectorView.hpp.

template<typename T , bool is_array>

scalar_t& stan::VectorView< T, is_array, true >::operator[] | ( | int | i | ) | const
| inline

Definition at line 91 of file VectorView.hpp.

The documentation for this class was generated from the following file:

- stan/math/prim/scal/meta/VectorView.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.